@@ -44,7 +44,10 @@ def set_info_in_registry():
         API_REGISTRY.delete(key)
     else:
         del data['service']
+        address = data['address']
+        del data['address']
         API_REGISTRY.hmset(key, data)
+        API_REGISTRY.hset(key, address, data['host'])
     return success()
 
 # EOF
