@@ -15,6 +15,7 @@ import redis
 
 
 __all__ = [
+    'ADDRESS',
     'API_LOGS',
     'API_REGISTRY',
     'BLUEFLASK_LOGS',
@@ -22,7 +23,6 @@ __all__ = [
     'HOSTNAME',
     'HTTP_VERBS',
     'LOGS',
-    'LDAP_API',
     'REST_CLIENT_LOGS',
     'SERVICE_CODE',
     'SPYNE_LOGS'
@@ -37,10 +37,10 @@ SERVICE_CODE = CONFIG['APP']['service_code']
 API_REGISTRY = redis.Redis(db=15)
 # le registre est TOUJOURS installé sur le même hôte que sponge
 HOSTNAME = socket.gethostname().split('.')[0]
-LDAP_API = 'https://{host}.blueline.mg:{port}/api/v2'.format(
-    host=API_REGISTRY.hget('service:ldap-services', 'host').decode('utf-8'),
-    port=API_REGISTRY.hget('service:ldap-services', 'port').decode('utf-8')
-    )
+_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+_socket.connect(("41.204.103.205", 80))
+ADDRESS = _socket.getsockname()[0]
+
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
 
